@@ -375,6 +375,37 @@ beast.base.evolution.tree.TreeDistanceLogger beastlabs.evolution.tree.TreeDistan
 "SAScaleOperator" "sa.evolution.operators.SAScaleOperator"
 "SampledNodeDateRandomWalker" "sa.evolution.operators.SampledNodeDateRandomWalker"
 beast.evolution.speciation.BirthDeathSkylineDiversifiedSampling bdsky.evolution.speciation.BirthDeathSkylineDiversifiedSampling
+beast.math.distributions.BMTPrior bmodeltest.math.distributions.BMTPrior
+beast.math.distributions.NucleotideRevJumpSubstModelRatePrior bmodeltest.math.distributions.NucleotideRevJumpSubstModelRatePrior
+"NucleotideRevJumpSubstModel" "bmodeltest.evolution.substitutionmodel.NucleotideRevJumpSubstModel"
+"ModelFrequencies" "bmodeltest.evolution.substitutionmodel.ModelFrequencies"
+"BEASTModelTestSiteModel" "bmodeltest.evolution.sitemodel.BEASTModelTestSiteModel"
+"BMTMergeSplitOperator" "bmodeltest.evolution.operators.BMTMergeSplitOperator"
+"BMTExchangeOperator" "bmodeltest.evolution.operators.BMTExchangeOperator"
+"BMTScaleOperator" "bmodeltest.evolution.operators.BMTScaleOperator"
+"BMTBirthDeathOperator" "bmodeltest.evolution.operators.BMTBirthDeathOperator"
+"tree.MultiRateTreeFromNewick" "msbd.base.evolution.tree.MultiRateTreeFromNewick"
+"ExtendableRealParameter" "msbd.base.inference.parameter.ExtendableRealParameter"
+"StdBirthDeathDensity" "msbd.distributions.StdBirthDeathDensity"
+"StateChangeModel" "msbd.evolution.tree.StateChangeModel"
+"PointDistribution" "msbd.distributions.PointDistribution"
+"MRTSubtreeExchange" "msbd.evolution.operator.MRTSubtreeExchange"
+"MRTWilsonBalding" "msbd.evolution.operator.MRTWilsonBalding"
+"MultiRateTreeUniform" "msbd.evolution.operator.MultiRateTreeUniform"
+"NodeShiftRetype" "msbd.evolution.operator.NodeShiftRetype"
+"NodeRetype" "msbd.evolution.operator.NodeRetype"
+"AddRemoveColourWPropagation" "msbd.evolution.operator.AddRemoveColourWPropagation"
+"AddRemoveConnectedWPropagation" "msbd.evolution.operator.AddRemoveConnectedWPropagation"
+"MoveColourChange" "msbd.evolution.operator.MoveColourChange"
+"parameter.ExtendableRealParameter" "msbd.base.inference.parameter.ExtendableRealParameter"
+"MultiRateTreeFromNewick" "msbd.base.evolution.tree.MultiRateTreeFromNewick"
+beast.base.evolution.tree.MultiRateTreeFromNewick msbd.base.evolution.tree.MultiRateTreeFromNewick
+beast.base.evolution.tree.MultiRateTree msbd.base.evolution.tree.MultiRateTree
+beast.math.distributions.FossilCalibration cladeage.math.distributions.FossilCalibration
+beast.math.distributions.FossilPrior cladeage.math.distributions.FossilPrior
+beast.math.distributions.DuoFossilPrior cladeage.math.distributions.DuoFossilPrior
+beast.math.distributions.DuoFossilCalibration cladeage.math.distributions.DuoFossilCalibration
+beast.math.distributions.CompoundFossilPrior cladeage.math.distributions.CompoundFossilPrior
 '
 ;
 
