@@ -1529,6 +1529,8 @@ public class PackageManager {
         all_classes = null;
     }
     
+    /** use addURL(u, packageName, services) instead **/
+    @Deprecated
     public static void addURL(URL u) throws IOException {
     	BEASTClassLoader.classLoader.addURL(u);
 //        // ClassloaderUtil clu = new ClassloaderUtil();
@@ -2041,6 +2043,7 @@ public class PackageManager {
             if (customDir != null) {
                 String path = PackageManager.getBeastPackagePathProperty();
                 System.setProperty("BEAST_PACKAGE_PATH", (path != null ? path + ":" : "") +customDir);
+                System.setProperty("beast.user.package.dir", (path != null ? path + ":" : "") +customDir);
             }
 
             List<URL> urlList = getRepositoryURLs();
